@@ -4,13 +4,10 @@ use Moo;
 use MooX::LazierAttributes;
 use Types::Standard qw/Str ArrayRef HashRef/;
 
-our $VERSION = '0.04';
-
-use feature qw/switch/;
-no warnings 'experimental::smartmatch';
-
 extends 'Pod::Simple';
 
+our $VERSION = '0.05';
+
 attributes(
     pod => [ rw, ArrayRef, { lzy_array, clr } ],
     section => [ rw, HashRef, { lzy_hash, clr } ],
@@ -72,19 +69,18 @@ sub _handle_element_start {
 sub _handle_text {
     my $el_name = $_[0]->element_name || 'join';
     $_[0]->clear_element_name;
-    given ( $_[0]->pod_elements->{$el_name} ) {
-        when ('content') {
-            my $el_args = {
-                text         => $_[1],
-                element_name => $el_name,
-                content      => $_[0]->section->{content},
-            };
-            $_[0]->section->{content} =
-              $_[0]->_parse_text( 'content', $el_args );
-        }
-        when ('title') {
-            $_[0]->section->{title} = $_[1];
-        }
+    my $pel = $_[0]->pod_elements->{$el_name};
+    if ($pel =~ m#content#) {
+        my $el_args = {
+            text         => $_[1],
+            element_name => $el_name,
+            content      => $_[0]->section->{content},
+        };
+        $_[0]->section->{content} =
+          $_[0]->_parse_text( 'content', $el_args );
+    }
+    elsif ($pel =~ m!title!) {
+        $_[0]->section->{title} = $_[1];
     }
 }
 
@@ -125,9 +121,7 @@ Pod::Simpler::Aoh - Parse pod into an array of hashes.
 
 =head1 VERSION
 
-Version 0.04
-
-=cut
+Version 0.05
 
 =head1 SYNOPSIS
 
